selectiontools.Selection
========================

.. abjad-lineage:: abjad.tools.selectiontools.Selection.Selection

.. autoclass:: abjad.tools.selectiontools.Selection.Selection

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.selectiontools.Selection.Selection.get_duration
      ~abjad.tools.selectiontools.Selection.Selection.get_spanners
      ~abjad.tools.selectiontools.Selection.Selection.__add__
      ~abjad.tools.selectiontools.Selection.Selection.__contains__
      ~abjad.tools.selectiontools.Selection.Selection.__eq__
      ~abjad.tools.selectiontools.Selection.Selection.__format__
      ~abjad.tools.selectiontools.Selection.Selection.__getitem__
      ~abjad.tools.selectiontools.Selection.Selection.__hash__
      ~abjad.tools.selectiontools.Selection.Selection.__illustrate__
      ~abjad.tools.selectiontools.Selection.Selection.__len__
      ~abjad.tools.selectiontools.Selection.Selection.__ne__
      ~abjad.tools.selectiontools.Selection.Selection.__radd__
      ~abjad.tools.selectiontools.Selection.Selection.__repr__

Bases
-----

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.selectiontools.Selection.Selection.get_duration
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.get_spanners
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__add__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__contains__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__eq__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__format__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__getitem__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__hash__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__illustrate__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__len__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__ne__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__radd__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.__repr__
   :noindex:
